@@ -9,7 +9,7 @@ from django.utils.translation import gettext_lazy as _
 from django.views.decorators.cache import cache_page
 from django.views.generic.base import RedirectView
 from django.views.i18n import JavaScriptCatalog
-from rest_framework_simplejwt.views import token_obtain_sliding, token_refresh_sliding
+from rest_framework_simplejwt.views import token_obtain_pair, token_refresh
 
 from .rest_framework.views import DownloadUrlView, UploadParamsView
 
@@ -25,9 +25,8 @@ urlpatterns = [
 # Vendor
 urlpatterns += [
     path('api-auth/', include('rest_framework.urls')),
-    path('api/token/', token_obtain_sliding, name='token_obtain'),
-    path('api/token/refresh/', token_refresh_sliding, name='token_refresh'),
-    # path('rest-auth/', include('rest_auth.urls')),
+    path('api/token/', token_obtain_pair, name='token_obtain_pair'),
+    path('api/token/refresh/', token_refresh, name='token_refresh'),
     # path('search/', include('haystack.urls'))
 ]
 # Railgun S
